This code, now known as OpenMDAO1, is now supplanted by the OpenMDAO 2.0.x Alpha. 

The OpenMDAO 1.7.3 codebase repo has been renamed to OpenMDAO1, and it resides 
here at https://github.com/OpenMDAO/OpenMDAO1

The OpenMDAO 2.0.x code has taken the name OpenMDAO, 
and it resides at https://github.com/OpenMDAO/OpenMDAO.

Installation of 2.0.x code will now work with `pip install openmdao`.  
Installation of 1.7.3 code will now only work with a version specifier: `pip install openmdao==1.7.3`

To use the OpenMDAO v0.x legacy version
 (versions 0.13.0 and older) of the OpenMDAO-Framework, go here:
https://github.com/OpenMDAO/OpenMDAO-Framework

To install OpenMDAO 1.X :
Install Python, Pip, Numpy, and Scipy.
(Anaconda Python, comes bundled with everything you need:   http://continuum.io ).

Next, clone OpenMDAO repository:

    git clone https://github.com/OpenMDAO/OpenMDAO1.git

Lastly, install it in development mode (from the parent directory):

    pip install -e OpenMDAO1

For more information, visit our website at:
http://openmdao.org

or read our docs at:
http://openmdao.org/docs
